@@ -326,77 +326,6 @@ cross_tabulate <- function(.df, ...,
   eval_tidy(call, data = .df)
 }
 
-#' An interlude in a magrittr pipeline
-#'
-#' The given language is executed, with the pronoun "." set to .df
-#' (usually the data frame sent through the pipeline),
-#' but the results are ignored, and the next line in the pipeline gets the unchanged data.
-#' Any executed code is allowed to edit variables which already exist in the
-#' calling environment. This is useful to store intermediate results.
-#'
-#' Note: Detection of the calling environment is not solved cleanly;
-#' it cannot be excluded that it fails under specific circumstances.
-#'
-#' @param .df Data argument, typical "first" argument in dplyr verbs
-#' @param .language Language
-#'
-#' @return Unchanged .df
-#' @export
-#'
-#' @examples
-#' library(tibble)
-#' library(magrittr)
-#' library(dplyr)
-#' x <- c() # now x exists in the calling env
-#' tibble(a=1, b=2) %>%
-#'    mutate(b=a+3) %>%
-#'    interlude(x <- .$b) %>%
-#'    mutate(a=a+1)
-#' # x is set to 4
-interlude <- function(.df, .language)
-{
-  .language <- enquo(.language)
-  if (quo_is_missing(.language))
-    return(.df)
-
-  expr <- quo_squash(.language)
-  lang_env <- get_env(.language)
-  exec_env <- child_env(lang_env)
-  # Provide the "." binding
-  env_bind(exec_env, !!!list(. = .df))
-
-  # execute
-  eval_bare(expr, exec_env)
-
-  # If the language assigned variables, they are contained in exec_env.
-  # First, find the frame that actually called interlude() (there are magrittr pipe frames in between)
-  # Second, check if an assigned variable is bound in the actually calling environment
-  # Third, if it already exists, assign the new value.
-  stack <- call_stack()[-1]
-  my_func_name <- as.character(match.call()[[1]])
-  pipe_env <- NULL
-  for (i in seq_along(stack))
-  {
-    if (str_detect(expr_text(stack[[i]]$expr), my_func_name))
-    {
-      pipe_env <- stack[[i+1]]$env
-    }
-  }
-
-  if (!is_null(pipe_env))
-  {
-    for (name in env_names(exec_env))
-    {
-      if (name != "." && env_has(pipe_env, name))
-      {
-        assign(name, env_get(exec_env, name), envir = lang_env, inherits = T)
-      }
-    }
-  }
-
-  .df
-}
-
 #' Format numeric columns for display
 #'
 #' Combines \code{\link{mutate_at}()} and \code{\link{as_formatted_number}()}
